==> bsl-language-server-0.20.0-ra.2.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/IncorrectUseLikeInQuery.md <==
# Некорректное использование 'ПОДОБНО' (IncorrectUseLikeInQuery)

|   Тип    |    Поддерживаются<br>языки    | Важность |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |                        Теги                        |
|:--------:|:-----------------------------:|:--------:|:------------------------------:|:-----------------------------------:|:--------------------------------------------------:|
| `Ошибка` |             `BSL`             | `Важный` |              `Да`              |                `10`                 |       `standard`<br>`sql`<br>`unpredictable`       |

<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
<!-- Описание диагностики заполняется вручную. Необходимо понятным языком описать смысл и схему работу -->

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->

При использовании в тексте запроса оператора `ПОДОБНО` допустимо использовать только
- константные строковые литералы
- параметры запроса

Запрещается формировать строку шаблона при помощи вычислений, использовать конкатенацию строк средствами языка запросов.

Запросы, в которых управляющие символы шаблона оператора `ПОДОБНО` находятся в полях запроса или в вычисляемых выражениях, по-разному интерпретируются на различных СУБД.

## Источники
<!-- Необходимо указывать ссылки на все источники, из которых почерпнута информация для создания диагностики -->
<!-- Примеры источников

* Источник: [Стандарт: Тексты модулей](https://its.1c.ru/db/v8std#content:456:hdoc)
* Полезная информация: [Отказ от использования модальных окон](https://its.1c.ru/db/metod8dev#content:5272:hdoc)
* Источник: [Cognitive complexity, ver. 1.4](https://www.sonarsource.com/docs/CognitiveComplexity.pdf) -->

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:IncorrectUseLikeInQuery-off
// BSLLS:IncorrectUseLikeInQuery-on
```

### Параметр конфигурационного файла

```json
"IncorrectUseLikeInQuery": false
```

==> bsl-language-server-0.24.0.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/IncorrectUseLikeInQuery.md <==
# Некорректное использование 'ПОДОБНО' (IncorrectUseLikeInQuery)

|   Тип    |    Поддерживаются<br>языки    | Важность |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |                        Теги                        |
|:--------:|:-----------------------------:|:--------:|:------------------------------:|:-----------------------------------:|:--------------------------------------------------:|
| `Ошибка` |             `BSL`             | `Важный` |              `Да`              |                `10`                 |       `standard`<br>`sql`<br>`unpredictable`       |

<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
<!-- Описание диагностики заполняется вручную. Необходимо понятным языком описать смысл и схему работу -->

При использовании в тексте запроса оператора `ПОДОБНО` допустимо использовать только
- константные строковые литералы
- параметры запроса

Запрещается формировать строку шаблона при помощи вычислений, использовать конкатенацию строк средствами языка запросов.

Запросы, в которых управляющие символы шаблона оператора `ПОДОБНО` находятся в полях запроса или в вычисляемых выражениях, 
по-разному интерпретируются на различных СУБД (MS SQL и PostgreSQL).

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->

### Конкатенация строк средствами языка

Допустимо:

```
Реквизит ПОДОБНО "123%"
```

Недопустимо:

```
Реквизит ПОДОБНО "123" + "%"
Реквизит ПОДОБНО Таблица.Шаблон
```

### Управляющие символы шаблона оператора ПОДОБНО находятся в полях запроса или в вычисляемых выражениях

Например, вместо:

```
Запрос = Новый Запрос("
|ВЫБРАТЬ
|    Товары.Ссылка
|ИЗ
|    Справочник.Товары КАК Товары
|ГДЕ
|    Товары.СтранаПроисхождения.Наименование ПОДОБНО &ШаблонНазванияСтраны + "_"
|");

Запрос.УстановитьПараметр("ШаблонНазванияСтраны", "ЧА");
```

Необходимо использовать:

```
Запрос = Новый Запрос("
|ВЫБРАТЬ
|    Товары.Ссылка
|ИЗ
|    Справочник.Товары КАК Товары
|ГДЕ
|    Товары.СтранаПроисхождения.Наименование ПОДОБНО &ШаблонНазванияСтраны
|");

Запрос.УстановитьПараметр("ШаблонНазванияСтраны", "ЧА_");
```

## Источники
<!-- Необходимо указывать ссылки на все источники, из которых почерпнута информация для создания диагностики -->
<!-- Примеры источников

* Источник: [Стандарт: Тексты модулей](https://its.1c.ru/db/v8std#content:456:hdoc)
* Полезная информация: [Отказ от использования модальных окон](https://its.1c.ru/db/metod8dev#content:5272:hdoc)
* Источник: [Cognitive complexity, ver. 1.4](https://www.sonarsource.com/docs/CognitiveComplexity.pdf) -->

- Источник: [Стандарт: Особенности использования в запросах оператора ПОДОБНО](https://its.1c.ru/db/v8std/content/726/hdoc?ysclid=l3g3fkmxsx)

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:IncorrectUseLikeInQuery-off
// BSLLS:IncorrectUseLikeInQuery-on
```

### Параметр конфигурационного файла

```json
"IncorrectUseLikeInQuery": false
```
